@@ -284,7 +284,7 @@ class AIOBlock(object):
         """
         if self._iocb.aio_lio_opcode != libaio.IO_CMD_POLL:
             raise AttributeError
-        return self._iocb.u.c.buf.value
+        return self._iocb.u.c.buf
 
     @event_mask.setter
     def event_mask(self, value):
@@ -299,7 +299,7 @@ class AIOBlock(object):
 
         Only available in mode != AIOBLOCK_MODE_POLL.
         """
-        return self._iocb.u.c.offset.value
+        return self._iocb.u.c.offset
 
     @offset.setter
     def offset(self, value):
